@@ -434,6 +434,8 @@ Filter::filterListConfig *Filter::getFilterList(const char *from, const char *to
 		filterListPointer->to.assign(to);
 		filterListPointer->globalFilter = global;
 		filterListPointer->filter = 0;
+		filterListPointer->type = "";
+		filterListPointer->typeDescription = "";
 		filterListPointer->legacyType = false;
 		filterListPointer->sourceOnly = false;
 		filterListPointer->sourceServiceSupported = false;
